@@ -3,9 +3,10 @@ import click
 
 from .libsimenv.autocomplete import complete_chkpt_names, complete_app_names
 from .libsimenv.app_manifest import *
-from .libsimenv.checkpoints_globber import *
+from .libsimenv.checkpoints_db import *
 from .libsimenv.makefile_generator.makefile_generator import *
 from .libsimenv.manifest_db import *
+from .libsimenv.shcmd_utils import add_prefix_to_stdin_file_in_shcmd
 
 from .libsimenv.utils import *
 
@@ -21,8 +22,6 @@ def mkgen(ctx, app_name, checkpoint):
     """
     manifest_db_path = ctx.obj['manifest_db_path']
     checkpoints_archive_path = ctx.obj['checkpoints_archive_path']
-    if checkpoint and not checkpoints_archive_path:
-        fatal("Checkpoints archive root must be provided if you want to load a checkpoint.")
 
     try:
         manifest = load_from_manifest_db(app_name, manifest_db_path)
@@ -37,15 +36,18 @@ def mkgen(ctx, app_name, checkpoint):
         fatal("%s has a malformed manifest (%s)" % (app_name, ve))
     else:
         print(
-            "Generating makefile simenv for app %s%s" % (
+            "Generating makefile for app %s%s" % (
                 app_name, ", checkpoint %s" % checkpoint if checkpoint else "")
         )
         app_name = manifest["app_name"]
         app_cmd = manifest["app_cmd"]
+        app_cmd = add_prefix_to_stdin_file_in_shcmd(app_cmd, "$(SIMENV_SYSROOT)/$(APP_INIT_CWD)/")
         app_init_cwd = manifest["app_init_cwd"]
         app_memsize = manifest["app_memsize"]
+        ckpt_flag_override = os.getenv("ATOOL_SIMENV_SIM_CKPT_LOAD_FLAG", default="-c")
+
         if checkpoint:
-            sim_flags = "-f%s" % get_checkpoint_abspath(checkpoints_archive_path, app_name, checkpoint)
+            sim_flags = ckpt_flag_override + get_checkpoint_abspath(checkpoints_archive_path, app_name, checkpoint)
         else:
             sim_flags = ""
         generated_makefile = generate_makefile(
